Angle

Struct Angle 

pub struct Angle { /* private fields */ }
The ‘Angle’ struct can be used to deal with angles in a common way.

Example

use measurements::Angle;

let whole_cake = Angle::from_degrees(360.0);
let pieces = 6.0;
let slice = whole_cake / pieces;
println!("Each slice will be {} degrees", slice.as_degrees());

Implementations

Source

impl Angle

pub fn from_degrees(degrees: f64) -> Angle

Create a new Angle from a floating point value in degrees

pub fn from_radians(radians: f64) -> Angle

Create a new Angle from a floating point value in radians

pub fn as_degrees(&self) -> f64

Convert this Angle to a floating point value in degrees

pub fn as_radians(&self) -> f64

Convert this Angle to a floating point value in radians

pub fn cos(&self) -> f64

Calculate the cosine of this angle

pub fn sin(&self) -> f64

Calculate the sine of this angle

pub fn sin_cos(&self) -> (f64, f64)

Calculate the sine and cosine of this angle

pub fn tan(&self) -> f64

Calculate the tangent of this angle

pub fn asin(num: f64) -> Angle

Calculate the arcsine of a number

pub fn acos(num: f64) -> Angle

Calculate the arccosine of a number

pub fn atan(num: f64) -> Angle

Calculate the arctangent of a number