pub struct Angle { /* private fields */ }Expand description
The ‘Angle’ struct can be used to deal with angles in a common way.
Example
use measurements::Angle;
let whole_cake = Angle::from_degrees(360.0);
let pieces = 6.0;
let slice = whole_cake / pieces;
println!("Each slice will be {} degrees", slice.as_degrees());Implementations
Sourceimpl Angle
impl Angle
Sourcepub fn from_degrees(degrees: f64) -> Angle
pub fn from_degrees(degrees: f64) -> Angle
Create a new Angle from a floating point value in degrees
Sourcepub fn from_radians(radians: f64) -> Angle
pub fn from_radians(radians: f64) -> Angle
Create a new Angle from a floating point value in radians
Sourcepub fn as_degrees(&self) -> f64
pub fn as_degrees(&self) -> f64
Convert this Angle to a floating point value in degrees
Sourcepub fn as_radians(&self) -> f64
pub fn as_radians(&self) -> f64
Convert this Angle to a floating point value in radians